SetBit

Trait SetBit 

pub trait SetBit<I, B> {
    type Output;
}
A type operator that, when implemented for unsigned integer N, sets the bit at position I to B.

Required Associated Types

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<N, I, B> SetBit<I, B> for N
where N: PrivateSetBit<I, B>, PrivateSetBitOut<N, I, B>: Trim,

Source

type Output = <<N as PrivateSetBit<I, B>>::Output as Trim>::Output